@@ -23,7 +23,9 @@
 #'
 #' @examples
 #' # Create centroids set
-#' centroids <- create_centroids(tas_lga, sf_id = "LGA_CODE16")
+#' centroids <- create_centroids(tas_lga, sf_id = "lga_code_2016")
+#' # Smaller set for faster example
+#' centroids <- centroids[1:10,] 
 #' # Create hexagon location grid
 #' data(capital_cities)
 #' grid <- create_grid(centroids = centroids, hex_size = 0.2, buffer_dist = 1.2)
@@ -32,18 +34,24 @@
 #'   centroids = centroids,
 #'   hex_grid = grid,
 #'   hex_size = 0.2, # same size used in create_grid
-#'   hex_filter = 10,
+#'   hex_filter = 3,
 #'   focal_points = capital_cities,
-#'   width = 30, verbose = TRUE
+#'   width = 30, 
+#'   verbose = TRUE
 #' )
-#' # same column used in create_centroids
+#' # NEXT: 
 #' # create a set of hexagon points for plotting
-#' fort_hex <- fortify_hexagon(data = hex_allocated, sf_id = "LGA_CODE16", hex_size = 0.2)
-#' # plot the hexagons
+#' # using fortify_hexagon, and
+#' # plot the hexagons with geom_polygon, see vignette
 allocate <-
   function(centroids, hex_grid, sf_id = names(centroids)[1], hex_size, hex_filter, focal_points = NULL, order_sf_id = NULL, width = 30, verbose) {
     
     # If there are focal points
+    if (!(any(grepl("lon", colnames(focal_points))))) {
+      return(message("Missing longitude column in focal points data set. Please provide a data set with longitude and latitude columns."))
+    } else if (!(any(grepl("lat", colnames(focal_points))))) {
+      return(message("Missing latitude column in focal points data set. Please provide a data set with longitude and latitude columns."))
+    }
     
     # consider focal point distance - if they were provided
     if (!is.null(focal_points)) {
