@@ -19,23 +19,23 @@
 #'
 #' @format A simple features data frame with 99 rows and 15 variables:
 #' \describe{
-#'   \item{SA2_MAIN16}{complete code of the Statistical Area}
-#'   \item{SA2_5DIG16}{simple code for the Statistical Area}
-#'   \item{SA2_NAME16}{name of the Statistical Area}
-#'   \item{SA3_CODE16}{code for the SA3 containing the Statistical Area}
-#'   \item{SA3_NAME16}{name of the SA3 containing the Statistical Area}
-#'   \item{SA4_CODE16}{code for the SA4 containing the Statistical Area}
-#'   \item{SA4_NAME16}{name of the SA4 containing the Statistical Area}
-#'   \item{GCC_CODE16}{code for the Greater Capital City region containing
+#'   \item{sa2_main_2016}{complete code of the Statistical Area}
+#'   \item{sa2_5dig_2016}{simple code for the Statistical Area}
+#'   \item{sa2_name_2016}{name of the Statistical Area}
+#'   \item{sa3_code_2016}{code for the SA3 containing the Statistical Area}
+#'   \item{sa3_name_2016}{name of the SA3 containing the Statistical Area}
+#'   \item{sa4_code_2016}{code for the SA4 containing the Statistical Area}
+#'   \item{sa4_name_2016}{name of the SA4 containing the Statistical Area}
+#'   \item{gcc_code_2016}{code for the Greater Capital City region containing
 #'    the Statistical Area}
-#'   \item{GCC_NAME16}{name of the Greater Capital City region containing
+#'   \item{gcc_name_2016}{name of the Greater Capital City region containing
 #'   the Statistical Area}
-#'   \item{STE_CODE16}{code for the state containing the Statistical Area}
-#'   \item{STE_NAME16}{name of the state containing the Statistical Area}
-#'   \item{AREASQKM16}{area contained in the polygon}
+#'   \item{ste_code_2016}{code for the state containing the Statistical Area}
+#'   \item{ste_name_2016}{name of the state containing the Statistical Area}
+#'   \item{areasqkm_2016}{area contained in the polygon}
 #'   \item{id}{distinguishes SA2 regions}
 #'   \item{population}{amount of people living within the region}
-#'   \item{SA2_CODE16}{code of the Statistical Area}
+#'   \item{sa2_code_2016}{code of the Statistical Area}
 #' }
 #'
 #' @name tas_sa2
@@ -49,15 +49,29 @@
 #'
 #' @format A simple features data frame with 39 rows and 6 variables:
 #' \describe{
-#'   \item{LGA_CODE16}{code for the Local Government Area}
-#'   \item{LGA_NAME16}{name of the Local Government Area}
-#'   \item{STE_CODE16}{code for the state containing the Local Government Area}
-#'   \item{STE_NAME16}{name of the state containing the Local Government Area}
-#'   \item{AREA_SQKM}{area contained in the polygon}
+#'   \item{lga_code_2016}{code for the Local Government Area}
+#'   \item{lga_name_2016}{name of the Local Government Area}
+#'   \item{ste_code_2016}{code for the state containing the Local Government Area}
+#'   \item{ste_name_2016}{name of the state containing the Local Government Area}
+#'   \item{areasqkm_2016}{area contained in the polygon}
 #'   \item{geometry}{describes where on Earth the polygon is located}
 #' }
 "tas_lga"
 
+#' The hexagon centres for polygons of Tasmanian Local Government Areas in 2016.
+#'
+#' A tibble dataset containing the processed data for all Australian LGAs in
+#' 2016. Each point corresponds to hexagon centre.
+#'
+#' @format A simple features data frame with 39 rows and 6 variables:
+#' \describe{
+#'   \item{lga_code_2016}{code for the Local Government Area}
+#'   \item{longitude, latitude}{polygon centroid}
+#'   \item{points, focal_longitude, focal_latitude, focal_dist, focal_angle}{Focal point (capital city) information used for each polygon/hexagon}
+#'   \item{rownumber}{row number, in case it can be useful}
+#'   \item{hex_long, hex_lat, hex_id}{hexagon centre and id}
+#' }
+"tas_lga_hexctr"
 
 #' The amount of homeless people in each Statistical Area at Level 2 in 2016.
 #'
@@ -66,7 +80,7 @@
 #' @format A data frame with 545 rows and 2 variables:
 #' \describe{
 #'   \item{homeless}{amount of homeless people}
-#'   \item{SA2_NAME16}{name of the Statistical Area at Level 2}
+#'   \item{sa2_name_2016}{name of the Statistical Area at Level 2}
 #' }
 "homeless"
 
